@@ -27,12 +27,12 @@ pub use event::{
     CreateEventInput, DeleteEventInput, GetEventInput, GetEventsInstancesInput, UpdateEventInput,
 };
 pub use nettu_scheduler_domain::{
-    providers::google::*, BusyCalendar, CalendarEventReminder, RRuleOptions, ScheduleRule,
-    SyncedCalendar, SyncedCalendarProvider, TimePlan, ID,
+    providers::google::*, BusyCalendar, CalendarEventReminder, RRuleOptions, RoundRobinAlgorithm,
+    ScheduleRule, ServiceMultiPersonOptions, SyncedCalendar, SyncedCalendarProvider, TimePlan, ID,
 };
 pub use schedule::{CreateScheduleInput, UpdateScheduleInput};
 pub use service::{
-    AddServiceUserInput, CreateBookingIntendInput, GetServiceBookingSlotsInput,
+    AddServiceUserInput, CreateBookingIntendInput, CreateServiceInput, GetServiceBookingSlotsInput,
     RemoveServiceUserInput, UpdateServiceUserInput,
 };
 pub use shared::{KVMetadata, MetadataFindInput};
